@@ -428,7 +428,7 @@ def install(package_name, force_reinstall=False, installation_dir=None):
 
     # See if this package requires a grant.
     if not info["requires_grant"]:
-        url = f"{OPTIONS.server}/hpack/download/{package_name}/{version}.zip"
+        url = f"{OPTIONS.server}/hpackage/download/{package_name}/{version}.zip"
     else:
         if authentication is None:
             authentication = OPTIONS.require_authentication()
@@ -716,7 +716,7 @@ def upload(package_name_or_path, requires_grant, auto_publish):
         with zip_path.open("rb") as open_file:
             open_file.seek(index)
             while True:
-                data = open_file.read(CHUNK_SIZE)
+                data = open_file.read(CHUNK_SIZE * 10)
                 if not data:
                     break
                 result = _call_sidefx("hpack.upload_chunk", authentication,
@@ -735,7 +735,7 @@ def upload(package_name_or_path, requires_grant, auto_publish):
     finally:
         zip_path.unlink()
 
-    print(f"{OPTIONS.server}/hpack/package/{package_name}")
+    print(f"{OPTIONS.server}/hpackage/package/{package_name}")
 
 
 def _compute_md5_checksum(file_path, only_first_bytes=None):
@@ -855,23 +855,23 @@ def _validate_package_json(json_path):
             exit=False)
         return False
 
-    if "hpack" not in j:
-        print_error(f'{json_path} does not contain an "hpack" entry',
+    if "hpackage" not in j:
+        print_error(f'{json_path} does not contain an "hpackage" entry',
             exit=False)
         return False
 
-    if not isinstance(j["hpack"], dict):
-        print_error(f'In {json_path}, "hpack" should be a JSON object',
+    if not isinstance(j["hpackage"], dict):
+        print_error(f'In {json_path}, "hpackage" should be a JSON object',
             exit=False)
         return False
 
-    if "version" not in j["hpack"]:
+    if "version" not in j["hpackage"]:
         print_error(
-            f'In {json_path}, "hpack" does not contain a "version" entry',
+            f'In {json_path}, "hpackage" does not contain a "version" entry',
             exit=False)
         return False
 
-    version = j["hpack"]["version"]
+    version = j["hpackage"]["version"]
     if not isinstance(version, str):
         print_error(f'In {json_path}, "version" should be a string',
             exit=False)
@@ -939,7 +939,7 @@ def _validate_package_json(json_path):
                     is_valid = False
 
     for key in ("min_versions", "max_versions"):
-        versions = j["hpack"].get(key)
+        versions = j["hpackage"].get(key)
         if versions is None:
             continue
         if not isinstance(versions, dict):
@@ -947,7 +947,7 @@ def _validate_package_json(json_path):
                 f'In {json_path}, "{key}" is not a JSON object', exit=False)
             is_valid = False
             continue
-        for name, version_str in j["hpack"][key].items():
+        for name, version_str in j["hpackage"][key].items():
             if not isinstance(name, str) or not isinstance(version_str, str):
                 print_error(
                     f'In {json_path}, "{key}" entries must be strings',
@@ -1089,7 +1089,7 @@ def _read_package_info_from_json(json_path):
     if not package_name:
         return None, None
 
-    version = package_json.get("hpack", {}).get("version")
+    version = package_json.get("hpackage", {}).get("version")
     if not version:
         return None, None
 
@@ -1100,7 +1100,7 @@ def _read_package_info_from_json(json_path):
     for list_key, key, operation in (
             ("min_versions", "min_version", "minimum"),
             ("max_versions", "max_version", "maximum")):
-        for requires_name, version in package_json["hpack"].get(
+        for requires_name, version in package_json["hpackage"].get(
                 list_key, {}).items():
             if requires_name in requires_dict:
                 requires_dict[requires_name][key] = version
@@ -1897,7 +1897,8 @@ def _download_file(
                 _print_progress_bar(
                     size_downloaded / file_size,
                     suffix=package_name_and_version)
-    message = f"\rSuccessfully installed {package_name_and_version}"
+    message = (f"\rSuccessfully installed {package_name_and_version} to"
+        f" {path.parent}")
     print(f"{message:<{_num_terminal_cols()}}")
 
     # Verify that we got the right final file size and checksum.
